@@ -1,3 +1,5 @@
+#![deny(missing_docs)]
+#![allow(missing_docs)] // Contents are self describing for now.
 #[derive(Clone, Copy, Debug)]
 pub enum OckamError {
     None,
@@ -19,6 +21,8 @@ pub enum OckamError {
     InvalidHubResponse,
     InvalidParameter,
     SecureChannelVerificationFailed,
+    SecureChannelCannotBeAuthenticated,
+    NoSuchParser,
 }
 
 impl OckamError {
